@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-pyviddler
+This provides a Python wrapper around Viddler's v2 API.
 """
 __version_info__ = {
     'major': 0,
-    'minor': 3,
+    'minor': 4,
     'micro': 0,
     'releaselevel': 'final',
     'serial': 1
